# Using 115 for hosting image.

## Installation

You can install from [pypi](https://pypi.org/project/p115imghost/)

```console
pip install -U p115imghost
```

## Usage

```console
$ p115imghost -h

```
